==> jangaroo-sdk-0.9.3.zip: joo/classes/js/Event.js <==
joo.classLoader.prepare("package js",/*{*/
"public class Event",1,function($$private){;return[ 
  "public native function get type"/*() : String*/,

  "public native function preventDefault"/*() : void*/,

  "public native function stopPropagation"/*() : void*/,

  "public native function get pageX"/*() : Number*/,

  "public native function set pageX"/*(n : Number) : void*/,

  "public native function get pageY"/*() : Number*/,

  "public native function set pageY"/*(n : Number) : void*/,

  "public native function get clientX"/*() : Number*/,

  "public native function get clientY"/*() : Number*/,

  "public native function get screenX"/*() : Number*/,

  "public native function get screenY"/*() : Number*/,

  "public native function get keyCode"/*() : Number*/,

  "public native function get fromElement"/*() : Element*/,

  "public native function get toElement"/*() : Element*/,

  "public native function get target"/*() : Element*/,

  "public native function set target"/*(e : Element) : void*/, // only for IE
  "public native function get relatedTarget"/*() : Element*/,

  "public native function set relatedTarget"/*(e : Element) : void*/, // only for IE
  "public native function get shiftKey"/*() : Boolean*/,

  "public native function get shiftLeft"/*() : Boolean*/,

  "public native function get ctrlKey"/*() : Boolean*/,

  "public native function get ctrlLeft"/*() : Boolean*/,

  "public native function get altKey"/*() : Boolean*/,

  "public native function get metaKey"/*() : Boolean*/,

  "public native function get srcElement"/*() : Element*/, // IE only
  "public native function get returnValue"/*() : Boolean*/, // IE only
  "public native function set returnValue"/*(val : Boolean) : void*/, // IE only
  "public native function get cancelBubble"/*() : Boolean*/, // IE only
  "public native function set cancelBubble"/*(val : Boolean) : void*/, // IE only
  "public native function get touches"/*() : Array*/,  // iPhone only
  "public native function initMouseEvent"/*(eventType : String, param2 : Boolean, param3 : Boolean, view:*, detail:*,
                                        screenX : int, screenY : int, clientX : int, clientY : int,
                                        ctrlKey : Boolean, altKey : Boolean, shiftKey : Boolean, metaKey : Boolean,
                                        param14 : *, param15 : *) : void*/,
];},[],[], "0.8.0", "0.9.3"
);

==> jangaroo-sdk-0.9.13.zip: joo/classes/js/Event.js <==
joo.classLoader.prepare("package js",/*{*/
"public class Event",1,function($$private){return[ 
  "public native function get type"/*() : String*/,

  "public native function preventDefault"/*() : void*/,

  "public native function stopPropagation"/*() : void*/,

  "public native function get pageX"/*() : Number*/,

  "public native function set pageX"/*(n : Number) : void*/,

  "public native function get pageY"/*() : Number*/,

  "public native function set pageY"/*(n : Number) : void*/,

  "public native function get clientX"/*() : Number*/,

  "public native function get clientY"/*() : Number*/,

  "public native function get screenX"/*() : Number*/,

  "public native function get screenY"/*() : Number*/,

  "public native function get keyCode"/*() : Number*/,

  "public native function get fromElement"/*() : Element*/,

  "public native function get toElement"/*() : Element*/,

  "public native function get target"/*() : Element*/,

  "public native function set target"/*(e : Element) : void*/, // only for IE
  "public native function get relatedTarget"/*() : Element*/,

  "public native function set relatedTarget"/*(e : Element) : void*/, // only for IE
  "public native function get shiftKey"/*() : Boolean*/,

  "public native function get shiftLeft"/*() : Boolean*/,

  "public native function get ctrlKey"/*() : Boolean*/,

  "public native function get ctrlLeft"/*() : Boolean*/,

  "public native function get altKey"/*() : Boolean*/,

  "public native function get metaKey"/*() : Boolean*/,

  "public native function get srcElement"/*() : Element*/, // IE only
  "public native function get returnValue"/*() : Boolean*/, // IE only
  "public native function set returnValue"/*(val : Boolean) : void*/, // IE only
  "public native function get cancelBubble"/*() : Boolean*/, // IE only
  "public native function set cancelBubble"/*(val : Boolean) : void*/, // IE only
  "public native function get touches"/*() : Array*/,  // iPhone only
  "public native function initMouseEvent"/*(eventType : String, param2 : Boolean, param3 : Boolean, view:*, detail:*,
                                        screenX : int, screenY : int, clientX : int, clientY : int,
                                        ctrlKey : Boolean, altKey : Boolean, shiftKey : Boolean, metaKey : Boolean,
                                        param14 : *, param15 : *) : void*/,
undefined];},[],[], "0.8.0", "0.9.12"
);
